#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class MailFilterRuleAction:
    def __init__(self):
        self.name = None
        self.clientProperties = None
        pass


class __MailFilterRuleActionSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MailFilterRuleAction()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.mailbox.api.rules.actions.MailFilterRuleActionName import MailFilterRuleActionName
        from netbluemind.mailbox.api.rules.actions.MailFilterRuleActionName import __MailFilterRuleActionNameSerDer__
        nameValue = value['name']
        instance.name = __MailFilterRuleActionNameSerDer__().parse(nameValue)
        clientPropertiesValue = value['clientProperties']
        instance.clientProperties = serder.MapSerDer(
            serder.STRING).parse(clientPropertiesValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.mailbox.api.rules.actions.MailFilterRuleActionName import MailFilterRuleActionName
        from netbluemind.mailbox.api.rules.actions.MailFilterRuleActionName import __MailFilterRuleActionNameSerDer__
        nameValue = value.name
        instance["name"] = __MailFilterRuleActionNameSerDer__().encode(nameValue)
        clientPropertiesValue = value.clientProperties
        instance["clientProperties"] = serder.MapSerDer(
            serder.STRING).encode(clientPropertiesValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class VCardExplanatory:
    def __init__(self):
        self.urls = None
        self.categories = None
        self.note = None
        pass


class __VCardExplanatorySerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = VCardExplanatory()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.addressbook.api.VCardExplanatoryUrl import VCardExplanatoryUrl
        from netbluemind.addressbook.api.VCardExplanatoryUrl import __VCardExplanatoryUrlSerDer__
        urlsValue = value['urls']
        instance.urls = serder.ListSerDer(
            __VCardExplanatoryUrlSerDer__()).parse(urlsValue)
        from netbluemind.tag.api.TagRef import TagRef
        from netbluemind.tag.api.TagRef import __TagRefSerDer__
        categoriesValue = value['categories']
        instance.categories = serder.ListSerDer(
            __TagRefSerDer__()).parse(categoriesValue)
        noteValue = value['note']
        instance.note = serder.STRING.parse(noteValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.addressbook.api.VCardExplanatoryUrl import VCardExplanatoryUrl
        from netbluemind.addressbook.api.VCardExplanatoryUrl import __VCardExplanatoryUrlSerDer__
        urlsValue = value.urls
        instance["urls"] = serder.ListSerDer(
            __VCardExplanatoryUrlSerDer__()).encode(urlsValue)
        from netbluemind.tag.api.TagRef import TagRef
        from netbluemind.tag.api.TagRef import __TagRefSerDer__
        categoriesValue = value.categories
        instance["categories"] = serder.ListSerDer(
            __TagRefSerDer__()).encode(categoriesValue)
        noteValue = value.note
        instance["note"] = serder.STRING.encode(noteValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class MailFilterRule:
    def __init__(self):
        self.id = None
        self.client = None
        self.type = None
        self.trigger = None
        self.deferred = None
        self.active = None
        self.name = None
        self.clientProperties = None
        self.conditions = None
        self.actions = None
        self.stop = None
        pass


class __MailFilterRuleSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MailFilterRule()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        idValue = value['id']
        instance.id = serder.LONG.parse(idValue)
        clientValue = value['client']
        instance.client = serder.STRING.parse(clientValue)
        from netbluemind.mailbox.api.rules.MailFilterRuleType import MailFilterRuleType
        from netbluemind.mailbox.api.rules.MailFilterRuleType import __MailFilterRuleTypeSerDer__
        typeValue = value['type']
        instance.type = __MailFilterRuleTypeSerDer__().parse(typeValue)
        from netbluemind.mailbox.api.rules.MailFilterRuleTrigger import MailFilterRuleTrigger
        from netbluemind.mailbox.api.rules.MailFilterRuleTrigger import __MailFilterRuleTriggerSerDer__
        triggerValue = value['trigger']
        instance.trigger = __MailFilterRuleTriggerSerDer__().parse(triggerValue)
        deferredValue = value['deferred']
        instance.deferred = serder.BOOLEAN.parse(deferredValue)
        activeValue = value['active']
        instance.active = serder.BOOLEAN.parse(activeValue)
        nameValue = value['name']
        instance.name = serder.STRING.parse(nameValue)
        clientPropertiesValue = value['clientProperties']
        instance.clientProperties = serder.MapSerDer(
            serder.STRING).parse(clientPropertiesValue)
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleCondition import MailFilterRuleCondition
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleCondition import __MailFilterRuleConditionSerDer__
        conditionsValue = value['conditions']
        instance.conditions = serder.ListSerDer(
            __MailFilterRuleConditionSerDer__()).parse(conditionsValue)
        from netbluemind.mailbox.api.rules.actions.MailFilterRuleAction import MailFilterRuleAction
        from netbluemind.mailbox.api.rules.actions.MailFilterRuleAction import __MailFilterRuleActionSerDer__
        actionsValue = value['actions']
        instance.actions = serder.ListSerDer(
            __MailFilterRuleActionSerDer__()).parse(actionsValue)
        stopValue = value['stop']
        instance.stop = serder.BOOLEAN.parse(stopValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        idValue = value.id
        instance["id"] = serder.LONG.encode(idValue)
        clientValue = value.client
        instance["client"] = serder.STRING.encode(clientValue)
        from netbluemind.mailbox.api.rules.MailFilterRuleType import MailFilterRuleType
        from netbluemind.mailbox.api.rules.MailFilterRuleType import __MailFilterRuleTypeSerDer__
        typeValue = value.type
        instance["type"] = __MailFilterRuleTypeSerDer__().encode(typeValue)
        from netbluemind.mailbox.api.rules.MailFilterRuleTrigger import MailFilterRuleTrigger
        from netbluemind.mailbox.api.rules.MailFilterRuleTrigger import __MailFilterRuleTriggerSerDer__
        triggerValue = value.trigger
        instance["trigger"] = __MailFilterRuleTriggerSerDer__().encode(
            triggerValue)
        deferredValue = value.deferred
        instance["deferred"] = serder.BOOLEAN.encode(deferredValue)
        activeValue = value.active
        instance["active"] = serder.BOOLEAN.encode(activeValue)
        nameValue = value.name
        instance["name"] = serder.STRING.encode(nameValue)
        clientPropertiesValue = value.clientProperties
        instance["clientProperties"] = serder.MapSerDer(
            serder.STRING).encode(clientPropertiesValue)
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleCondition import MailFilterRuleCondition
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleCondition import __MailFilterRuleConditionSerDer__
        conditionsValue = value.conditions
        instance["conditions"] = serder.ListSerDer(
            __MailFilterRuleConditionSerDer__()).encode(conditionsValue)
        from netbluemind.mailbox.api.rules.actions.MailFilterRuleAction import MailFilterRuleAction
        from netbluemind.mailbox.api.rules.actions.MailFilterRuleAction import __MailFilterRuleActionSerDer__
        actionsValue = value.actions
        instance["actions"] = serder.ListSerDer(
            __MailFilterRuleActionSerDer__()).encode(actionsValue)
        stopValue = value.stop
        instance["stop"] = serder.BOOLEAN.encode(stopValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class ItemValueExists:
    def __init__(self):
        self.itemExists = None
        self.valueExists = None
        pass


class __ItemValueExistsSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ItemValueExists()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        itemExistsValue = value['itemExists']
        instance.itemExists = serder.BOOLEAN.parse(itemExistsValue)
        valueExistsValue = value['valueExists']
        instance.valueExists = serder.BOOLEAN.parse(valueExistsValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        itemExistsValue = value.itemExists
        instance["itemExists"] = serder.BOOLEAN.encode(itemExistsValue)
        valueExistsValue = value.valueExists
        instance["valueExists"] = serder.BOOLEAN.encode(valueExistsValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class ItemVersion:
    def __init__(self):
        self.id = None
        self.version = None
        self.timestamp = None
        pass


class __ItemVersionSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ItemVersion()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        idValue = value['id']
        instance.id = serder.LONG.parse(idValue)
        versionValue = value['version']
        instance.version = serder.LONG.parse(versionValue)
        timestampValue = value['timestamp']
        instance.timestamp = serder.DATE.parse(timestampValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        idValue = value.id
        instance["id"] = serder.LONG.encode(idValue)
        versionValue = value.version
        instance["version"] = serder.LONG.encode(versionValue)
        timestampValue = value.timestamp
        instance["timestamp"] = serder.DATE.encode(timestampValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class InstallationVersion:
    def __init__(self):
        self.databaseVersion = None
        self.softwareVersion = None
        self.versionName = None
        self.needsUpgrade = None
        pass


class __InstallationVersionSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = InstallationVersion()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        databaseVersionValue = value['databaseVersion']
        instance.databaseVersion = serder.STRING.parse(databaseVersionValue)
        softwareVersionValue = value['softwareVersion']
        instance.softwareVersion = serder.STRING.parse(softwareVersionValue)
        versionNameValue = value['versionName']
        instance.versionName = serder.STRING.parse(versionNameValue)
        needsUpgradeValue = value['needsUpgrade']
        instance.needsUpgrade = serder.BOOLEAN.parse(needsUpgradeValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        databaseVersionValue = value.databaseVersion
        instance["databaseVersion"] = serder.STRING.encode(
            databaseVersionValue)
        softwareVersionValue = value.softwareVersion
        instance["softwareVersion"] = serder.STRING.encode(
            softwareVersionValue)
        versionNameValue = value.versionName
        instance["versionName"] = serder.STRING.encode(versionNameValue)
        needsUpgradeValue = value.needsUpgrade
        instance["needsUpgrade"] = serder.BOOLEAN.encode(needsUpgradeValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class DelegationRule:
    def __init__(self):
        self.delegatorCalendarUid = None
        self.delegateUids = None
        self.delegatorUid = None
        self.keepCopy = None
        self.readOnly = None
        pass


class __DelegationRuleSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = DelegationRule()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        delegatorCalendarUidValue = value['delegatorCalendarUid']
        instance.delegatorCalendarUid = serder.STRING.parse(
            delegatorCalendarUidValue)
        delegateUidsValue = value['delegateUids']
        instance.delegateUids = serder.ListSerDer(
            serder.STRING).parse(delegateUidsValue)
        delegatorUidValue = value['delegatorUid']
        instance.delegatorUid = serder.STRING.parse(delegatorUidValue)
        keepCopyValue = value['keepCopy']
        instance.keepCopy = serder.BOOLEAN.parse(keepCopyValue)
        readOnlyValue = value['readOnly']
        instance.readOnly = serder.BOOLEAN.parse(readOnlyValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        delegatorCalendarUidValue = value.delegatorCalendarUid
        instance["delegatorCalendarUid"] = serder.STRING.encode(
            delegatorCalendarUidValue)
        delegateUidsValue = value.delegateUids
        instance["delegateUids"] = serder.ListSerDer(
            serder.STRING).encode(delegateUidsValue)
        delegatorUidValue = value.delegatorUid
        instance["delegatorUid"] = serder.STRING.encode(delegatorUidValue)
        keepCopyValue = value.keepCopy
        instance["keepCopy"] = serder.BOOLEAN.encode(keepCopyValue)
        readOnlyValue = value.readOnly
        instance["readOnly"] = serder.BOOLEAN.encode(readOnlyValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.directory.api.DirBaseValue import DirBaseValue
from netbluemind.directory.api.DirBaseValue import __DirBaseValueSerDer__


class ExternalUser (DirBaseValue):
    def __init__(self):
        DirBaseValue.__init__(self)
        self.contactInfos = None
        pass


class __ExternalUserSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ExternalUser()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        __DirBaseValueSerDer__().parseInternal(value, instance)
        from netbluemind.addressbook.api.VCard import VCard
        from netbluemind.addressbook.api.VCard import __VCardSerDer__
        contactInfosValue = value['contactInfos']
        instance.contactInfos = __VCardSerDer__().parse(contactInfosValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):
        __DirBaseValueSerDer__().encodeInternal(value, instance)

        from netbluemind.addressbook.api.VCard import VCard
        from netbluemind.addressbook.api.VCard import __VCardSerDer__
        contactInfosValue = value.contactInfos
        instance["contactInfos"] = __VCardSerDer__().encode(contactInfosValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class VNote:
    def __init__(self):
        self.height = None
        self.width = None
        self.posX = None
        self.posY = None
        self.color = None
        self.body = None
        self.subject = None
        self.categories = None
        pass


class __VNoteSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = VNote()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        heightValue = value['height']
        instance.height = serder.INT.parse(heightValue)
        widthValue = value['width']
        instance.width = serder.INT.parse(widthValue)
        posXValue = value['posX']
        instance.posX = serder.INT.parse(posXValue)
        posYValue = value['posY']
        instance.posY = serder.INT.parse(posYValue)
        from netbluemind.notes.api.VNoteColor import VNoteColor
        from netbluemind.notes.api.VNoteColor import __VNoteColorSerDer__
        colorValue = value['color']
        instance.color = __VNoteColorSerDer__().parse(colorValue)
        bodyValue = value['body']
        instance.body = serder.STRING.parse(bodyValue)
        subjectValue = value['subject']
        instance.subject = serder.STRING.parse(subjectValue)
        from netbluemind.tag.api.TagRef import TagRef
        from netbluemind.tag.api.TagRef import __TagRefSerDer__
        categoriesValue = value['categories']
        instance.categories = serder.ListSerDer(
            __TagRefSerDer__()).parse(categoriesValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        heightValue = value.height
        instance["height"] = serder.INT.encode(heightValue)
        widthValue = value.width
        instance["width"] = serder.INT.encode(widthValue)
        posXValue = value.posX
        instance["posX"] = serder.INT.encode(posXValue)
        posYValue = value.posY
        instance["posY"] = serder.INT.encode(posYValue)
        from netbluemind.notes.api.VNoteColor import VNoteColor
        from netbluemind.notes.api.VNoteColor import __VNoteColorSerDer__
        colorValue = value.color
        instance["color"] = __VNoteColorSerDer__().encode(colorValue)
        bodyValue = value.body
        instance["body"] = serder.STRING.encode(bodyValue)
        subjectValue = value.subject
        instance["subject"] = serder.STRING.encode(subjectValue)
        from netbluemind.tag.api.TagRef import TagRef
        from netbluemind.tag.api.TagRef import __TagRefSerDer__
        categoriesValue = value.categories
        instance["categories"] = serder.ListSerDer(
            __TagRefSerDer__()).encode(categoriesValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class MessageBodyRecipient:
    def __init__(self):
        self.kind = None
        self.address = None
        self.dn = None
        pass


class __MessageBodyRecipientSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MessageBodyRecipient()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.backend.mail.api.MessageBodyRecipientKind import MessageBodyRecipientKind
        from netbluemind.backend.mail.api.MessageBodyRecipientKind import __MessageBodyRecipientKindSerDer__
        kindValue = value['kind']
        instance.kind = __MessageBodyRecipientKindSerDer__().parse(kindValue)
        addressValue = value['address']
        instance.address = serder.STRING.parse(addressValue)
        dnValue = value['dn']
        instance.dn = serder.STRING.parse(dnValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.backend.mail.api.MessageBodyRecipientKind import MessageBodyRecipientKind
        from netbluemind.backend.mail.api.MessageBodyRecipientKind import __MessageBodyRecipientKindSerDer__
        kindValue = value.kind
        instance["kind"] = __MessageBodyRecipientKindSerDer__().encode(kindValue)
        addressValue = value.address
        instance["address"] = serder.STRING.encode(addressValue)
        dnValue = value.dn
        instance["dn"] = serder.STRING.encode(dnValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class ImportMailboxItemsStatus:
    def __init__(self):
        self.doneIds = None
        self.status = None
        pass


class __ImportMailboxItemsStatusSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ImportMailboxItemsStatus()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.backend.mail.api.ImportMailboxItemsStatusImportedMailboxItem import ImportMailboxItemsStatusImportedMailboxItem
        from netbluemind.backend.mail.api.ImportMailboxItemsStatusImportedMailboxItem import __ImportMailboxItemsStatusImportedMailboxItemSerDer__
        doneIdsValue = value['doneIds']
        instance.doneIds = serder.ListSerDer(
            __ImportMailboxItemsStatusImportedMailboxItemSerDer__()).parse(doneIdsValue)
        from netbluemind.backend.mail.api.ImportMailboxItemsStatusImportStatus import ImportMailboxItemsStatusImportStatus
        from netbluemind.backend.mail.api.ImportMailboxItemsStatusImportStatus import __ImportMailboxItemsStatusImportStatusSerDer__
        statusValue = value['status']
        instance.status = __ImportMailboxItemsStatusImportStatusSerDer__().parse(statusValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.backend.mail.api.ImportMailboxItemsStatusImportedMailboxItem import ImportMailboxItemsStatusImportedMailboxItem
        from netbluemind.backend.mail.api.ImportMailboxItemsStatusImportedMailboxItem import __ImportMailboxItemsStatusImportedMailboxItemSerDer__
        doneIdsValue = value.doneIds
        instance["doneIds"] = serder.ListSerDer(
            __ImportMailboxItemsStatusImportedMailboxItemSerDer__()).encode(doneIdsValue)
        from netbluemind.backend.mail.api.ImportMailboxItemsStatusImportStatus import ImportMailboxItemsStatusImportStatus
        from netbluemind.backend.mail.api.ImportMailboxItemsStatusImportStatus import __ImportMailboxItemsStatusImportStatusSerDer__
        statusValue = value.status
        instance["status"] = __ImportMailboxItemsStatusImportStatusSerDer__().encode(
            statusValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class AccessTokenInfo:
    def __init__(self):
        self.status = None
        self.externalAuthEndPointUrl = None
        self.internalRedirectUrl = None
        self.applicationId = None
        self.state = None
        self.codeChallenge = None
        self.codeChallengeMethod = None
        self.responseType = None
        self.scope = None
        self.url = None
        pass


class __AccessTokenInfoSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = AccessTokenInfo()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.authentication.api.AccessTokenInfoTokenStatus import AccessTokenInfoTokenStatus
        from netbluemind.authentication.api.AccessTokenInfoTokenStatus import __AccessTokenInfoTokenStatusSerDer__
        statusValue = value['status']
        instance.status = __AccessTokenInfoTokenStatusSerDer__().parse(statusValue)
        externalAuthEndPointUrlValue = value['externalAuthEndPointUrl']
        instance.externalAuthEndPointUrl = serder.STRING.parse(
            externalAuthEndPointUrlValue)
        internalRedirectUrlValue = value['internalRedirectUrl']
        instance.internalRedirectUrl = serder.STRING.parse(
            internalRedirectUrlValue)
        applicationIdValue = value['applicationId']
        instance.applicationId = serder.STRING.parse(applicationIdValue)
        stateValue = value['state']
        instance.state = serder.STRING.parse(stateValue)
        codeChallengeValue = value['codeChallenge']
        instance.codeChallenge = serder.STRING.parse(codeChallengeValue)
        codeChallengeMethodValue = value['codeChallengeMethod']
        instance.codeChallengeMethod = serder.STRING.parse(
            codeChallengeMethodValue)
        responseTypeValue = value['responseType']
        instance.responseType = serder.STRING.parse(responseTypeValue)
        scopeValue = value['scope']
        instance.scope = serder.STRING.parse(scopeValue)
        urlValue = value['url']
        instance.url = serder.STRING.parse(urlValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.authentication.api.AccessTokenInfoTokenStatus import AccessTokenInfoTokenStatus
        from netbluemind.authentication.api.AccessTokenInfoTokenStatus import __AccessTokenInfoTokenStatusSerDer__
        statusValue = value.status
        instance["status"] = __AccessTokenInfoTokenStatusSerDer__().encode(
            statusValue)
        externalAuthEndPointUrlValue = value.externalAuthEndPointUrl
        instance["externalAuthEndPointUrl"] = serder.STRING.encode(
            externalAuthEndPointUrlValue)
        internalRedirectUrlValue = value.internalRedirectUrl
        instance["internalRedirectUrl"] = serder.STRING.encode(
            internalRedirectUrlValue)
        applicationIdValue = value.applicationId
        instance["applicationId"] = serder.STRING.encode(applicationIdValue)
        stateValue = value.state
        instance["state"] = serder.STRING.encode(stateValue)
        codeChallengeValue = value.codeChallenge
        instance["codeChallenge"] = serder.STRING.encode(codeChallengeValue)
        codeChallengeMethodValue = value.codeChallengeMethod
        instance["codeChallengeMethod"] = serder.STRING.encode(
            codeChallengeMethodValue)
        responseTypeValue = value.responseType
        instance["responseType"] = serder.STRING.encode(responseTypeValue)
        scopeValue = value.scope
        instance["scope"] = serder.STRING.encode(scopeValue)
        urlValue = value.url
        instance["url"] = serder.STRING.encode(urlValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilter import MailFilterRuleFilter
from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilter import __MailFilterRuleFilterSerDer__


class MailFilterRuleFilterContains (MailFilterRuleFilter):
    def __init__(self):
        MailFilterRuleFilter.__init__(self)
        self.comparator = None
        self.modifier = None
        self.values = None
        pass


class __MailFilterRuleFilterContainsSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MailFilterRuleFilterContains()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        __MailFilterRuleFilterSerDer__().parseInternal(value, instance)
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilterContainsComparator import MailFilterRuleFilterContainsComparator
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilterContainsComparator import __MailFilterRuleFilterContainsComparatorSerDer__
        comparatorValue = value['comparator']
        instance.comparator = __MailFilterRuleFilterContainsComparatorSerDer__().parse(
            comparatorValue)
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilterContainsModifier import MailFilterRuleFilterContainsModifier
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilterContainsModifier import __MailFilterRuleFilterContainsModifierSerDer__
        modifierValue = value['modifier']
        instance.modifier = __MailFilterRuleFilterContainsModifierSerDer__().parse(modifierValue)
        valuesValue = value['values']
        instance.values = serder.ListSerDer(serder.STRING).parse(valuesValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):
        __MailFilterRuleFilterSerDer__().encodeInternal(value, instance)

        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilterContainsComparator import MailFilterRuleFilterContainsComparator
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilterContainsComparator import __MailFilterRuleFilterContainsComparatorSerDer__
        comparatorValue = value.comparator
        instance["comparator"] = __MailFilterRuleFilterContainsComparatorSerDer__(
        ).encode(comparatorValue)
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilterContainsModifier import MailFilterRuleFilterContainsModifier
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilterContainsModifier import __MailFilterRuleFilterContainsModifierSerDer__
        modifierValue = value.modifier
        instance["modifier"] = __MailFilterRuleFilterContainsModifierSerDer__().encode(
            modifierValue)
        valuesValue = value.values
        instance["values"] = serder.ListSerDer(
            serder.STRING).encode(valuesValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class MailFilterForwarding:
    def __init__(self):
        self.enabled = None
        self.localCopy = None
        self.emails = None
        pass


class __MailFilterForwardingSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MailFilterForwarding()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        enabledValue = value['enabled']
        instance.enabled = serder.BOOLEAN.parse(enabledValue)
        localCopyValue = value['localCopy']
        instance.localCopy = serder.BOOLEAN.parse(localCopyValue)
        emailsValue = value['emails']
        instance.emails = serder.SetSerDer(serder.STRING).parse(emailsValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        enabledValue = value.enabled
        instance["enabled"] = serder.BOOLEAN.encode(enabledValue)
        localCopyValue = value.localCopy
        instance["localCopy"] = serder.BOOLEAN.encode(localCopyValue)
        emailsValue = value.emails
        instance["emails"] = serder.SetSerDer(
            serder.STRING).encode(emailsValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IServer_VERSION = "5.2.1577"


class IServer(BaseEndpoint):
    def __init__(self, apiKey, url, containerUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/servers/{containerUid}'
        self.containerUid_ = containerUid
        self.base = self.base.replace('{containerUid}', containerUid)

    def allComplete(self):
        postUri = "/_complete"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        from netbluemind.server.api.Server import Server
        from netbluemind.server.api.Server import __ServerSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__ServerSerDer__())), response)

    def assign(self, serverUid, domainUid, tag):
        postUri = "/{domainUid}/assignments/{serverUid}/_assign"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{serverUid}", serverUid)
        postUri = postUri.replace("{domainUid}", domainUid)
        queryParams = {'tag': tag}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def byAssignment(self, domainUid, tag):
        postUri = "/{domainUid}/byAssignment"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{domainUid}", domainUid)
        queryParams = {'tag': tag}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)

    def create(self, uid, srv):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.server.api.Server import Server
        from netbluemind.server.api.Server import __ServerSerDer__
        __data__ = __ServerSerDer__().encode(srv)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def delete(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getAssignments(self, domainUid):
        postUri = "/{domainUid}/assignments"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{domainUid}", domainUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        from netbluemind.server.api.Assignment import Assignment
        from netbluemind.server.api.Assignment import __AssignmentSerDer__
        return self.handleResult__(serder.ListSerDer(__AssignmentSerDer__()), response)

    def getComplete(self, uid):
        postUri = "/{uid}/complete"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        from netbluemind.server.api.Server import Server
        from netbluemind.server.api.Server import __ServerSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__ServerSerDer__()), response)

    def getServerAssignments(self, uid):
        postUri = "/{uid}/serverAssignments"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        from netbluemind.server.api.Assignment import Assignment
        from netbluemind.server.api.Assignment import __AssignmentSerDer__
        return self.handleResult__(serder.ListSerDer(__AssignmentSerDer__()), response)

    def getStatus(self, uid, ref):
        postUri = "/{uid}/command_status"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {'ref': ref}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        from netbluemind.server.api.CommandStatus import CommandStatus
        from netbluemind.server.api.CommandStatus import __CommandStatusSerDer__
        return self.handleResult__(__CommandStatusSerDer__(), response)

    def readFile(self, uid, path):
        postUri = "/{uid}/fs/{path}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        postUri = postUri.replace("{path}", path)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ByteArraySerDer, response)

    def setTags(self, uid, tags):
        postUri = "/{uid}/tags"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        __data__ = serder.ListSerDer(serder.STRING).encode(tags)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def submit(self, uid, argv):
        postUri = "/{uid}/submit_command"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        __data__ = serder.ArraySerDer(serder.STRING).encode(argv)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        return self.handleResult__(serder.STRING, response)

    def submitAndWait(self, uid, argv):
        postUri = "/{uid}/submit_command_and_wait"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        __data__ = serder.ArraySerDer(serder.STRING).encode(argv)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        from netbluemind.server.api.CommandStatus import CommandStatus
        from netbluemind.server.api.CommandStatus import __CommandStatusSerDer__
        return self.handleResult__(__CommandStatusSerDer__(), response)

    def unassign(self, serverUid, domainUid, tag):
        postUri = "/{domainUid}/assignments/{serverUid}/_unassign"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{serverUid}", serverUid)
        postUri = postUri.replace("{domainUid}", domainUid)
        queryParams = {'tag': tag}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def update(self, uid, srv):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.server.api.Server import Server
        from netbluemind.server.api.Server import __ServerSerDer__
        __data__ = __ServerSerDer__().encode(srv)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def writeFile(self, uid, path, content):
        postUri = "/{uid}/fs/{path}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        postUri = postUri.replace("{path}", path)
        __data__ = serder.ByteArraySerDer.encode(content)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IServer_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.mailbox.api.SimpleShardStats import SimpleShardStats
from netbluemind.mailbox.api.SimpleShardStats import __SimpleShardStatsSerDer__


class ShardStats (SimpleShardStats):
    def __init__(self):
        SimpleShardStats.__init__(self)
        self.topMailbox = None
        self.state = None
        pass


class __ShardStatsSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ShardStats()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        __SimpleShardStatsSerDer__().parseInternal(value, instance)
        from netbluemind.mailbox.api.ShardStatsMailboxStats import ShardStatsMailboxStats
        from netbluemind.mailbox.api.ShardStatsMailboxStats import __ShardStatsMailboxStatsSerDer__
        topMailboxValue = value['topMailbox']
        instance.topMailbox = serder.ListSerDer(
            __ShardStatsMailboxStatsSerDer__()).parse(topMailboxValue)
        from netbluemind.mailbox.api.ShardStatsState import ShardStatsState
        from netbluemind.mailbox.api.ShardStatsState import __ShardStatsStateSerDer__
        stateValue = value['state']
        instance.state = __ShardStatsStateSerDer__().parse(stateValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):
        __SimpleShardStatsSerDer__().encodeInternal(value, instance)

        from netbluemind.mailbox.api.ShardStatsMailboxStats import ShardStatsMailboxStats
        from netbluemind.mailbox.api.ShardStatsMailboxStats import __ShardStatsMailboxStatsSerDer__
        topMailboxValue = value.topMailbox
        instance["topMailbox"] = serder.ListSerDer(
            __ShardStatsMailboxStatsSerDer__()).encode(topMailboxValue)
        from netbluemind.mailbox.api.ShardStatsState import ShardStatsState
        from netbluemind.mailbox.api.ShardStatsState import __ShardStatsStateSerDer__
        stateValue = value.state
        instance["state"] = __ShardStatsStateSerDer__().encode(stateValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IMailboxes_VERSION = "5.2.1577"


class IMailboxes(BaseEndpoint):
    def __init__(self, apiKey, url, domainUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/mailboxes/{domainUid}'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}', domainUid)

    def addDomainRule(self, rule):
        postUri = "/_rules"
        __data__ = None
        __encoded__ = None
        from netbluemind.mailbox.api.rules.MailFilterRule import MailFilterRule
        from netbluemind.mailbox.api.rules.MailFilterRule import __MailFilterRuleSerDer__
        __data__ = __MailFilterRuleSerDer__().encode(rule)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(serder.LONG, response)

    def addMailboxRule(self, mailboxUid, rule):
        postUri = "/{mailboxUid}/_rules"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        from netbluemind.mailbox.api.rules.MailFilterRule import MailFilterRule
        from netbluemind.mailbox.api.rules.MailFilterRule import __MailFilterRuleSerDer__
        __data__ = __MailFilterRuleSerDer__().encode(rule)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(serder.LONG, response)

    def addMailboxRuleRelative(self, mailboxUid, position, anchorId, rule):
        postUri = "/{mailboxUid}/_rules/{position}/{anchorId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        postUri = postUri.replace("{position}", position)
        postUri = postUri.replace("{anchorId}", anchorId)
        from netbluemind.mailbox.api.rules.MailFilterRule import MailFilterRule
        from netbluemind.mailbox.api.rules.MailFilterRule import __MailFilterRuleSerDer__
        __data__ = __MailFilterRuleSerDer__().encode(rule)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(serder.LONG, response)

    def byEmail(self, email):
        postUri = "/_byemail"
        __data__ = None
        __encoded__ = None
        queryParams = {'email': email}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__MailboxSerDer__()), response)

    def byName(self, name):
        postUri = "/_byname"
        __data__ = None
        __encoded__ = None
        queryParams = {'name': name}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__MailboxSerDer__()), response)

    def byRouting(self, email):
        postUri = "/_byRouting"
        __data__ = None
        __encoded__ = None
        queryParams = {'email': email}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)

    def byType(self, email):
        postUri = "/_byType"
        __data__ = None
        __encoded__ = None
        queryParams = {'email': email}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)

    def create(self, uid, mailbox):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        __data__ = __MailboxSerDer__().encode(mailbox)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def delete(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def deleteDomainRule(self, id):
        postUri = "/_rules/{id}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{id}", id)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def deleteMailboxRule(self, mailboxUid, id):
        postUri = "/{mailboxUid}/_rules/{id}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        postUri = postUri.replace("{id}", id)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getComplete(self, uid):
        postUri = "/{uid}/complete"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__MailboxSerDer__()), response)

    def getDomainFilter(self):
        postUri = "/_filter"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.MailFilter import MailFilter
        from netbluemind.mailbox.api.MailFilter import __MailFilterSerDer__
        return self.handleResult__(__MailFilterSerDer__(), response)

    def getDomainRule(self, id):
        postUri = "/_rules/{id}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{id}", id)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.rules.MailFilterRule import MailFilterRule
        from netbluemind.mailbox.api.rules.MailFilterRule import __MailFilterRuleSerDer__
        return self.handleResult__(__MailFilterRuleSerDer__(), response)

    def getDomainRules(self):
        postUri = "/_rules"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.rules.MailFilterRule import MailFilterRule
        from netbluemind.mailbox.api.rules.MailFilterRule import __MailFilterRuleSerDer__
        return self.handleResult__(serder.ListSerDer(__MailFilterRuleSerDer__()), response)

    def getMailboxAccessControlList(self, mailboxUid):
        postUri = "/{mailboxUid}/_acls"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.acl.AccessControlEntry import AccessControlEntry
        from netbluemind.core.container.model.acl.AccessControlEntry import __AccessControlEntrySerDer__
        return self.handleResult__(serder.ListSerDer(__AccessControlEntrySerDer__()), response)

    def getMailboxConfig(self, uid):
        postUri = "/{uid}/_config"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.MailboxConfig import MailboxConfig
        from netbluemind.mailbox.api.MailboxConfig import __MailboxConfigSerDer__
        return self.handleResult__(__MailboxConfigSerDer__(), response)

    def getMailboxDelegationRule(self, mailboxUid):
        postUri = "/{mailboxUid}/_delegationRule"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.rules.DelegationRule import DelegationRule
        from netbluemind.mailbox.api.rules.DelegationRule import __DelegationRuleSerDer__
        return self.handleResult__(__DelegationRuleSerDer__(), response)

    def getMailboxFilter(self, mailboxUid):
        postUri = "/{mailboxUid}/_filter"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.MailFilter import MailFilter
        from netbluemind.mailbox.api.MailFilter import __MailFilterSerDer__
        return self.handleResult__(__MailFilterSerDer__(), response)

    def getMailboxForwarding(self, mailboxUid):
        postUri = "/{mailboxUid}/_forwarding"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.MailFilterForwarding import MailFilterForwarding
        from netbluemind.mailbox.api.MailFilterForwarding import __MailFilterForwardingSerDer__
        return self.handleResult__(__MailFilterForwardingSerDer__(), response)

    def getMailboxQuota(self, uid):
        postUri = "/{uid}/_quota"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.MailboxQuota import MailboxQuota
        from netbluemind.mailbox.api.MailboxQuota import __MailboxQuotaSerDer__
        return self.handleResult__(__MailboxQuotaSerDer__(), response)

    def getMailboxRule(self, mailboxUid, id):
        postUri = "/{mailboxUid}/_rules/{id}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        postUri = postUri.replace("{id}", id)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.rules.MailFilterRule import MailFilterRule
        from netbluemind.mailbox.api.rules.MailFilterRule import __MailFilterRuleSerDer__
        return self.handleResult__(__MailFilterRuleSerDer__(), response)

    def getMailboxRules(self, mailboxUid):
        postUri = "/{mailboxUid}/_rules"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.rules.MailFilterRule import MailFilterRule
        from netbluemind.mailbox.api.rules.MailFilterRule import __MailFilterRuleSerDer__
        return self.handleResult__(serder.ListSerDer(__MailFilterRuleSerDer__()), response)

    def getMailboxRulesByClient(self, mailboxUid, client):
        postUri = "/{mailboxUid}/_rulesByClient"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        queryParams = {'client': client}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.rules.MailFilterRule import MailFilterRule
        from netbluemind.mailbox.api.rules.MailFilterRule import __MailFilterRuleSerDer__
        return self.handleResult__(serder.ListSerDer(__MailFilterRuleSerDer__()), response)

    def getMailboxVacation(self, mailboxUid):
        postUri = "/{mailboxUid}/_vacation"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.MailFilterVacation import MailFilterVacation
        from netbluemind.mailbox.api.MailFilterVacation import __MailFilterVacationSerDer__
        return self.handleResult__(__MailFilterVacationSerDer__(), response)

    def getUnreadMessagesCount(self):
        postUri = "/_unread"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(serder.INT, response)

    def list(self):
        postUri = "/_list"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__MailboxSerDer__())), response)

    def listUids(self):
        postUri = "/_listUids"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)

    def moveMailboxRule(self, mailboxUid, id, direction):
        postUri = "/{mailboxUid}/_rules/{id}/{direction}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        postUri = postUri.replace("{id}", id)
        postUri = postUri.replace("{direction}", direction)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def moveMailboxRuleRelative(self, mailboxUid, id, position, anchorId):
        postUri = "/{mailboxUid}/_rules/{id}/{position}/{anchorId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        postUri = postUri.replace("{id}", id)
        postUri = postUri.replace("{position}", position)
        postUri = postUri.replace("{anchorId}", anchorId)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def multipleGet(self, uids):
        postUri = "/_mget"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__MailboxSerDer__())), response)

    def setDomainFilter(self, filter):
        postUri = "/_filter"
        __data__ = None
        __encoded__ = None
        from netbluemind.mailbox.api.MailFilter import MailFilter
        from netbluemind.mailbox.api.MailFilter import __MailFilterSerDer__
        __data__ = __MailFilterSerDer__().encode(filter)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def setMailboxAccessControlList(self, mailboxUid, accessControlEntries):
        postUri = "/{mailboxUid}/_acls"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        from netbluemind.core.container.model.acl.AccessControlEntry import AccessControlEntry
        from netbluemind.core.container.model.acl.AccessControlEntry import __AccessControlEntrySerDer__
        __data__ = serder.ListSerDer(
            __AccessControlEntrySerDer__()).encode(accessControlEntries)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def setMailboxDelegationRule(self, mailboxUid, delegationRule):
        postUri = "/{mailboxUid}/_delegationRule"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        from netbluemind.mailbox.api.rules.DelegationRule import DelegationRule
        from netbluemind.mailbox.api.rules.DelegationRule import __DelegationRuleSerDer__
        __data__ = __DelegationRuleSerDer__().encode(delegationRule)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def setMailboxFilter(self, mailboxUid, filter):
        postUri = "/{mailboxUid}/_filter"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        from netbluemind.mailbox.api.MailFilter import MailFilter
        from netbluemind.mailbox.api.MailFilter import __MailFilterSerDer__
        __data__ = __MailFilterSerDer__().encode(filter)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def setMailboxForwarding(self, mailboxUid, forwarding):
        postUri = "/{mailboxUid}/_forwarding"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        from netbluemind.mailbox.api.MailFilterForwarding import MailFilterForwarding
        from netbluemind.mailbox.api.MailFilterForwarding import __MailFilterForwardingSerDer__
        __data__ = __MailFilterForwardingSerDer__().encode(forwarding)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def setMailboxVacation(self, mailboxUid, vacation):
        postUri = "/{mailboxUid}/_vacation"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        from netbluemind.mailbox.api.MailFilterVacation import MailFilterVacation
        from netbluemind.mailbox.api.MailFilterVacation import __MailFilterVacationSerDer__
        __data__ = __MailFilterVacationSerDer__().encode(vacation)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def update(self, uid, mailbox):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        __data__ = __MailboxSerDer__().encode(mailbox)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def updateDomainRule(self, id, rule):
        postUri = "/_rules/{id}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{id}", id)
        from netbluemind.mailbox.api.rules.MailFilterRule import MailFilterRule
        from netbluemind.mailbox.api.rules.MailFilterRule import __MailFilterRuleSerDer__
        __data__ = __MailFilterRuleSerDer__().encode(rule)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def updateMailboxRule(self, mailboxUid, id, rule):
        postUri = "/{mailboxUid}/_rules/{id}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        postUri = postUri.replace("{id}", id)
        from netbluemind.mailbox.api.rules.MailFilterRule import MailFilterRule
        from netbluemind.mailbox.api.rules.MailFilterRule import __MailFilterRuleSerDer__
        __data__ = __MailFilterRuleSerDer__().encode(rule)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class AuthUser:
    def __init__(self):
        self.uid = None
        self.domainUid = None
        self.displayName = None
        self.value = None
        self.roles = None
        self.rolesByOU = None
        self.settings = None
        pass


class __AuthUserSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = AuthUser()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        uidValue = value['uid']
        instance.uid = serder.STRING.parse(uidValue)
        domainUidValue = value['domainUid']
        instance.domainUid = serder.STRING.parse(domainUidValue)
        displayNameValue = value['displayName']
        instance.displayName = serder.STRING.parse(displayNameValue)
        from netbluemind.user.api.User import User
        from netbluemind.user.api.User import __UserSerDer__
        valueValue = value['value']
        instance.value = __UserSerDer__().parse(valueValue)
        rolesValue = value['roles']
        instance.roles = serder.SetSerDer(serder.STRING).parse(rolesValue)
        rolesByOUValue = value['rolesByOU']
        instance.rolesByOU = serder.MapSerDer(
            serder.SetSerDer(serder.STRING)).parse(rolesByOUValue)
        settingsValue = value['settings']
        instance.settings = serder.MapSerDer(
            serder.STRING).parse(settingsValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        uidValue = value.uid
        instance["uid"] = serder.STRING.encode(uidValue)
        domainUidValue = value.domainUid
        instance["domainUid"] = serder.STRING.encode(domainUidValue)
        displayNameValue = value.displayName
        instance["displayName"] = serder.STRING.encode(displayNameValue)
        from netbluemind.user.api.User import User
        from netbluemind.user.api.User import __UserSerDer__
        valueValue = value.value
        instance["value"] = __UserSerDer__().encode(valueValue)
        rolesValue = value.roles
        instance["roles"] = serder.SetSerDer(serder.STRING).encode(rolesValue)
        rolesByOUValue = value.rolesByOU
        instance["rolesByOU"] = serder.MapSerDer(
            serder.SetSerDer(serder.STRING)).encode(rolesByOUValue)
        settingsValue = value.settings
        instance["settings"] = serder.MapSerDer(
            serder.STRING).encode(settingsValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder
from enum import Enum


class MailFilterRuleActionName(Enum):
    ADD_HEADER = 'ADD_HEADER'
    CATEGORIZE = 'CATEGORIZE'
    COPY = 'COPY'
    CUSTOM = 'CUSTOM'
    DEFERRED_ACTION = 'DEFERRED_ACTION'
    DISCARD = 'DISCARD'
    MARK_AS_DELETED = 'MARK_AS_DELETED'
    MARK_AS_IMPORTANT = 'MARK_AS_IMPORTANT'
    MARK_AS_READ = 'MARK_AS_READ'
    MOVE = 'MOVE'
    PRIORITIZE = 'PRIORITIZE'
    REDIRECT = 'REDIRECT'
    REMOVE_HEADERS = 'REMOVE_HEADERS'
    REPLY = 'REPLY'
    SET_FLAGS = 'SET_FLAGS'
    TRANSFER = 'TRANSFER'
    UNCATEGORIZE = 'UNCATEGORIZE'
    UNFOLLOW = 'UNFOLLOW'


class __MailFilterRuleActionNameSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MailFilterRuleActionName[value]
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = value.value
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IFileHosting_VERSION = "5.2.1577"


class IFileHosting(BaseEndpoint):
    def __init__(self, apiKey, url, domainUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/filehosting/{domainUid}'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}', domainUid)

    def delete(self, path):
        postUri = "/{path}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{path}", path)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def exists(self, path):
        postUri = "/{path}/_exists"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{path}", path)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
        return self.handleResult__(serder.BOOLEAN, response)

    def find(self, query):
        postUri = "/_find"
        __data__ = None
        __encoded__ = None
        queryParams = {'query': query}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
        from netbluemind.filehosting.api.FileHostingItem import FileHostingItem
        from netbluemind.filehosting.api.FileHostingItem import __FileHostingItemSerDer__
        return self.handleResult__(serder.ListSerDer(__FileHostingItemSerDer__()), response)

    def get(self, path):
        postUri = "/{path}/_content"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{path}", path)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
        return response.content

    def getConfiguration(self):
        postUri = "/_config"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
        from netbluemind.filehosting.api.Configuration import Configuration
        from netbluemind.filehosting.api.Configuration import __ConfigurationSerDer__
        return self.handleResult__(__ConfigurationSerDer__(), response)

    def info(self):
        postUri = "/_info"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
        from netbluemind.filehosting.api.FileHostingInfo import FileHostingInfo
        from netbluemind.filehosting.api.FileHostingInfo import __FileHostingInfoSerDer__
        return self.handleResult__(__FileHostingInfoSerDer__(), response)

    def list(self, path):
        postUri = "/_list"
        __data__ = None
        __encoded__ = None
        queryParams = {'path': path}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
        from netbluemind.filehosting.api.FileHostingItem import FileHostingItem
        from netbluemind.filehosting.api.FileHostingItem import __FileHostingItemSerDer__
        return self.handleResult__(serder.ListSerDer(__FileHostingItemSerDer__()), response)

    def share(self, path, downloadLimit, expirationDate):
        postUri = "/_share"
        __data__ = None
        __encoded__ = None
        queryParams = {'path': path, 'downloadLimit': downloadLimit,
                       'expirationDate': expirationDate}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
        from netbluemind.filehosting.api.FileHostingPublicLink import FileHostingPublicLink
        from netbluemind.filehosting.api.FileHostingPublicLink import __FileHostingPublicLinkSerDer__
        return self.handleResult__(__FileHostingPublicLinkSerDer__(), response)

    def store(self, path, document):
        postUri = "/{path}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{path}", path)
        __data__ = serder.STREAM.encode(document)
        __encoded__ = __data__
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def unShare(self, url):
        postUri = "/{url}/unshare"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{url}", url)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class MailFilterRuleCondition:
    def __init__(self):
        self.operator = None
        self.filter = None
        self.conditions = None
        self.clientProperties = None
        self.negate = None
        pass


class __MailFilterRuleConditionSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MailFilterRuleCondition()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleConditionOperator import MailFilterRuleConditionOperator
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleConditionOperator import __MailFilterRuleConditionOperatorSerDer__
        operatorValue = value['operator']
        instance.operator = __MailFilterRuleConditionOperatorSerDer__().parse(operatorValue)
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilter import MailFilterRuleFilter
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilter import __MailFilterRuleFilterSerDer__
        filterValue = value['filter']
        instance.filter = __MailFilterRuleFilterSerDer__().parse(filterValue)
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleCondition import MailFilterRuleCondition
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleCondition import __MailFilterRuleConditionSerDer__
        conditionsValue = value['conditions']
        instance.conditions = serder.ListSerDer(
            __MailFilterRuleConditionSerDer__()).parse(conditionsValue)
        clientPropertiesValue = value['clientProperties']
        instance.clientProperties = serder.MapSerDer(
            serder.STRING).parse(clientPropertiesValue)
        negateValue = value['negate']
        instance.negate = serder.BOOLEAN.parse(negateValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleConditionOperator import MailFilterRuleConditionOperator
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleConditionOperator import __MailFilterRuleConditionOperatorSerDer__
        operatorValue = value.operator
        instance["operator"] = __MailFilterRuleConditionOperatorSerDer__().encode(
            operatorValue)
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilter import MailFilterRuleFilter
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleFilter import __MailFilterRuleFilterSerDer__
        filterValue = value.filter
        instance["filter"] = __MailFilterRuleFilterSerDer__().encode(filterValue)
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleCondition import MailFilterRuleCondition
        from netbluemind.mailbox.api.rules.conditions.MailFilterRuleCondition import __MailFilterRuleConditionSerDer__
        conditionsValue = value.conditions
        instance["conditions"] = serder.ListSerDer(
            __MailFilterRuleConditionSerDer__()).encode(conditionsValue)
        clientPropertiesValue = value.clientProperties
        instance["clientProperties"] = serder.MapSerDer(
            serder.STRING).encode(clientPropertiesValue)
        negateValue = value.negate
        instance["negate"] = serder.BOOLEAN.encode(negateValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class CalendarSettingsData:
    def __init__(self):
        self.workingDays = None
        self.dayStart = None
        self.dayEnd = None
        self.minDuration = None
        self.timezoneId = None
        pass


class __CalendarSettingsDataSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = CalendarSettingsData()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.calendar.api.CalendarSettingsDataDay import CalendarSettingsDataDay
        from netbluemind.calendar.api.CalendarSettingsDataDay import __CalendarSettingsDataDaySerDer__
        workingDaysValue = value['workingDays']
        instance.workingDays = serder.ListSerDer(
            __CalendarSettingsDataDaySerDer__()).parse(workingDaysValue)
        dayStartValue = value['dayStart']
        instance.dayStart = serder.INT.parse(dayStartValue)
        dayEndValue = value['dayEnd']
        instance.dayEnd = serder.INT.parse(dayEndValue)
        minDurationValue = value['minDuration']
        instance.minDuration = serder.INT.parse(minDurationValue)
        timezoneIdValue = value['timezoneId']
        instance.timezoneId = serder.STRING.parse(timezoneIdValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.calendar.api.CalendarSettingsDataDay import CalendarSettingsDataDay
        from netbluemind.calendar.api.CalendarSettingsDataDay import __CalendarSettingsDataDaySerDer__
        workingDaysValue = value.workingDays
        instance["workingDays"] = serder.ListSerDer(
            __CalendarSettingsDataDaySerDer__()).encode(workingDaysValue)
        dayStartValue = value.dayStart
        instance["dayStart"] = serder.INT.encode(dayStartValue)
        dayEndValue = value.dayEnd
        instance["dayEnd"] = serder.INT.encode(dayEndValue)
        minDurationValue = value.minDuration
        instance["minDuration"] = serder.INT.encode(minDurationValue)
        timezoneIdValue = value.timezoneId
        instance["timezoneId"] = serder.STRING.encode(timezoneIdValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IJob_VERSION = "5.2.1577"


class IJob(BaseEndpoint):
    def __init__(self, apiKey, url):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/scheduledjobs'

    def cancel(self, jobId, domainName):
        postUri = "/_cancel/{jobId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{jobId}", jobId)
        queryParams = {'domainName': domainName}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IJob_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def deleteExecution(self, jobExecutionId):
        postUri = "/_deleteExecution"
        __data__ = None
        __encoded__ = None
        queryParams = {'jobExecutionId': jobExecutionId}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IJob_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def deleteExecutions(self, executions):
        postUri = "/_deleteExecutions"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.INT).encode(executions)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IJob_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getJobFromId(self, jobId):
        postUri = "/_job/{jobId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{jobId}", jobId)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IJob_VERSION}, data=__encoded__)
        from netbluemind.scheduledjob.api.Job import Job
        from netbluemind.scheduledjob.api.Job import __JobSerDer__
        return self.handleResult__(__JobSerDer__(), response)

    def getLogs(self, jobExecution, offset):
        postUri = "/_logs"
        __data__ = None
        __encoded__ = None
        from netbluemind.scheduledjob.api.JobExecution import JobExecution
        from netbluemind.scheduledjob.api.JobExecution import __JobExecutionSerDer__
        __data__ = __JobExecutionSerDer__().encode(jobExecution)
        __encoded__ = json.dumps(__data__)
        queryParams = {'offset': offset}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IJob_VERSION}, data=__encoded__)
        from netbluemind.scheduledjob.api.LogEntry import LogEntry
        from netbluemind.scheduledjob.api.LogEntry import __LogEntrySerDer__
        return self.handleResult__(serder.SetSerDer(__LogEntrySerDer__()), response)

    def searchExecution(self, query):
        postUri = "/_searchExecution"
        __data__ = None
        __encoded__ = None
        from netbluemind.scheduledjob.api.JobExecutionQuery import JobExecutionQuery
        from netbluemind.scheduledjob.api.JobExecutionQuery import __JobExecutionQuerySerDer__
        __data__ = __JobExecutionQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IJob_VERSION}, data=__encoded__)
        from netbluemind.scheduledjob.api.JobExecution import JobExecution
        from netbluemind.scheduledjob.api.JobExecution import __JobExecutionSerDer__
        from netbluemind.core.api.ListResult import ListResult
        from netbluemind.core.api.ListResult import __ListResultSerDer__
        return self.handleResult__(__ListResultSerDer__(__JobExecutionSerDer__()), response)

    def searchJob(self, query):
        postUri = "/_searchJob"
        __data__ = None
        __encoded__ = None
        from netbluemind.scheduledjob.api.JobQuery import JobQuery
        from netbluemind.scheduledjob.api.JobQuery import __JobQuerySerDer__
        __data__ = __JobQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IJob_VERSION}, data=__encoded__)
        from netbluemind.scheduledjob.api.Job import Job
        from netbluemind.scheduledjob.api.Job import __JobSerDer__
        from netbluemind.core.api.ListResult import ListResult
        from netbluemind.core.api.ListResult import __ListResultSerDer__
        return self.handleResult__(__ListResultSerDer__(__JobSerDer__()), response)

    def start(self, jobId, domainName):
        postUri = "/_start/{jobId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{jobId}", jobId)
        queryParams = {'domainName': domainName}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IJob_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def update(self, job):
        postUri = "/_updateJob"
        __data__ = None
        __encoded__ = None
        from netbluemind.scheduledjob.api.Job import Job
        from netbluemind.scheduledjob.api.Job import __JobSerDer__
        __data__ = __JobSerDer__().encode(job)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IJob_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.icalendar.api.ICalendarElement import ICalendarElement
from netbluemind.icalendar.api.ICalendarElement import __ICalendarElementSerDer__


class VEvent (ICalendarElement):
    def __init__(self):
        ICalendarElement.__init__(self)
        self.dtend = None
        self.transparency = None
        pass


class __VEventSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = VEvent()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        __ICalendarElementSerDer__().parseInternal(value, instance)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dtendValue = value['dtend']
        instance.dtend = __BmDateTimeSerDer__().parse(dtendValue)
        from netbluemind.calendar.api.VEventTransparency import VEventTransparency
        from netbluemind.calendar.api.VEventTransparency import __VEventTransparencySerDer__
        transparencyValue = value['transparency']
        instance.transparency = __VEventTransparencySerDer__().parse(transparencyValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):
        __ICalendarElementSerDer__().encodeInternal(value, instance)

        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dtendValue = value.dtend
        instance["dtend"] = __BmDateTimeSerDer__().encode(dtendValue)
        from netbluemind.calendar.api.VEventTransparency import VEventTransparency
        from netbluemind.calendar.api.VEventTransparency import __VEventTransparencySerDer__
        transparencyValue = value.transparency
        instance["transparency"] = __VEventTransparencySerDer__().encode(
            transparencyValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class Configuration:
    def __init__(self):
        self.autoDetachmentLimit = None
        self.maxFilesize = None
        self.retentionTime = None
        pass


class __ConfigurationSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = Configuration()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        autoDetachmentLimitValue = value['autoDetachmentLimit']
        instance.autoDetachmentLimit = serder.LONG.parse(
            autoDetachmentLimitValue)
        maxFilesizeValue = value['maxFilesize']
        instance.maxFilesize = serder.LONG.parse(maxFilesizeValue)
        retentionTimeValue = value['retentionTime']
        instance.retentionTime = serder.INT.parse(retentionTimeValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        autoDetachmentLimitValue = value.autoDetachmentLimit
        instance["autoDetachmentLimit"] = serder.LONG.encode(
            autoDetachmentLimitValue)
        maxFilesizeValue = value.maxFilesize
        instance["maxFilesize"] = serder.LONG.encode(maxFilesizeValue)
        retentionTimeValue = value.retentionTime
        instance["retentionTime"] = serder.INT.encode(retentionTimeValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class ItemFlagFilter:
    def __init__(self):
        self.must = None
        self.mustNot = None
        self.skipVersions = None
        self.skipExpunged = None
        pass


class __ItemFlagFilterSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ItemFlagFilter()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.core.container.model.ItemFlag import ItemFlag
        from netbluemind.core.container.model.ItemFlag import __ItemFlagSerDer__
        mustValue = value['must']
        instance.must = serder.CollectionSerDer(
            __ItemFlagSerDer__()).parse(mustValue)
        from netbluemind.core.container.model.ItemFlag import ItemFlag
        from netbluemind.core.container.model.ItemFlag import __ItemFlagSerDer__
        mustNotValue = value['mustNot']
        instance.mustNot = serder.CollectionSerDer(
            __ItemFlagSerDer__()).parse(mustNotValue)
        skipVersionsValue = value['skipVersions']
        instance.skipVersions = serder.SetSerDer(
            serder.LONG).parse(skipVersionsValue)
        skipExpungedValue = value['skipExpunged']
        instance.skipExpunged = serder.BOOLEAN.parse(skipExpungedValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.core.container.model.ItemFlag import ItemFlag
        from netbluemind.core.container.model.ItemFlag import __ItemFlagSerDer__
        mustValue = value.must
        instance["must"] = serder.CollectionSerDer(
            __ItemFlagSerDer__()).encode(mustValue)
        from netbluemind.core.container.model.ItemFlag import ItemFlag
        from netbluemind.core.container.model.ItemFlag import __ItemFlagSerDer__
        mustNotValue = value.mustNot
        instance["mustNot"] = serder.CollectionSerDer(
            __ItemFlagSerDer__()).encode(mustNotValue)
        skipVersionsValue = value.skipVersions
        instance["skipVersions"] = serder.SetSerDer(
            serder.LONG).encode(skipVersionsValue)
        skipExpungedValue = value.skipExpunged
        instance["skipExpunged"] = serder.BOOLEAN.encode(skipExpungedValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IExternalSystem_VERSION = "5.2.1577"


class IExternalSystem(BaseEndpoint):
    def __init__(self, apiKey, url):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/system/external'

    def getExternalSystem(self, systemIdentifier):
        postUri = "/{systemIdentifier}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{systemIdentifier}", systemIdentifier)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IExternalSystem_VERSION}, data=__encoded__)
        from netbluemind.system.api.ExternalSystem import ExternalSystem
        from netbluemind.system.api.ExternalSystem import __ExternalSystemSerDer__
        return self.handleResult__(__ExternalSystemSerDer__(), response)

    def getExternalSystems(self):
        postUri = ""
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IExternalSystem_VERSION}, data=__encoded__)
        from netbluemind.system.api.ExternalSystem import ExternalSystem
        from netbluemind.system.api.ExternalSystem import __ExternalSystemSerDer__
        return self.handleResult__(serder.ListSerDer(__ExternalSystemSerDer__()), response)

    def getExternalSystemsByAuthKind(self, authKinds):
        postUri = "/_by_authkind"
        __data__ = None
        __encoded__ = None
        from netbluemind.system.api.ExternalSystemAuthKind import ExternalSystemAuthKind
        from netbluemind.system.api.ExternalSystemAuthKind import __ExternalSystemAuthKindSerDer__
        __data__ = serder.SetSerDer(
            __ExternalSystemAuthKindSerDer__()).encode(authKinds)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IExternalSystem_VERSION}, data=__encoded__)
        from netbluemind.system.api.ExternalSystem import ExternalSystem
        from netbluemind.system.api.ExternalSystem import __ExternalSystemSerDer__
        return self.handleResult__(serder.ListSerDer(__ExternalSystemSerDer__()), response)

    def getLogo(self, systemIdentifier):
        postUri = "/{systemIdentifier}/_logo"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{systemIdentifier}", systemIdentifier)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IExternalSystem_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ByteArraySerDer, response)

    def testConnection(self, systemIdentifier, account):
        postUri = "/{systemIdentifier}/_test_connection"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{systemIdentifier}", systemIdentifier)
        from netbluemind.user.api.UserAccount import UserAccount
        from netbluemind.user.api.UserAccount import __UserAccountSerDer__
        __data__ = __UserAccountSerDer__().encode(account)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IExternalSystem_VERSION}, data=__encoded__)
        from netbluemind.system.api.ConnectionTestStatus import ConnectionTestStatus
        from netbluemind.system.api.ConnectionTestStatus import __ConnectionTestStatusSerDer__
        return self.handleResult__(__ConnectionTestStatusSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IDataProtect_VERSION = "5.2.1577"


class IDataProtect(BaseEndpoint):
    def __init__(self, apiKey, url):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/dataprotect'

    def forget(self, generationId):
        postUri = "/generations"
        __data__ = None
        __encoded__ = None
        queryParams = {'generationId': generationId}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDataProtect_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def getAvailableGenerations(self):
        postUri = "/generations"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDataProtect_VERSION}, data=__encoded__)
        from netbluemind.dataprotect.api.DataProtectGeneration import DataProtectGeneration
        from netbluemind.dataprotect.api.DataProtectGeneration import __DataProtectGenerationSerDer__
        return self.handleResult__(serder.ListSerDer(__DataProtectGenerationSerDer__()), response)

    def getContent(self, partGen):
        postUri = "/_content/{partGen}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{partGen}", partGen)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDataProtect_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def getRestoreCapabilities(self):
        postUri = "/restore/_capabilities"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDataProtect_VERSION}, data=__encoded__)
        from netbluemind.dataprotect.api.RestoreOperation import RestoreOperation
        from netbluemind.dataprotect.api.RestoreOperation import __RestoreOperationSerDer__
        return self.handleResult__(serder.ListSerDer(__RestoreOperationSerDer__()), response)

    def getRestoreCapabilitiesByTags(self, tags):
        postUri = "/restore/_capabilities_by_tags"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(tags)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDataProtect_VERSION}, data=__encoded__)
        from netbluemind.dataprotect.api.RestoreOperation import RestoreOperation
        from netbluemind.dataprotect.api.RestoreOperation import __RestoreOperationSerDer__
        return self.handleResult__(serder.ListSerDer(__RestoreOperationSerDer__()), response)

    def getRetentionPolicy(self):
        postUri = "/policy"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDataProtect_VERSION}, data=__encoded__)
        from netbluemind.dataprotect.api.RetentionPolicy import RetentionPolicy
        from netbluemind.dataprotect.api.RetentionPolicy import __RetentionPolicySerDer__
        return self.handleResult__(__RetentionPolicySerDer__(), response)

    def installFromGeneration(self, generationId):
        postUri = "/_install"
        __data__ = None
        __encoded__ = None
        queryParams = {'generationId': generationId}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDataProtect_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def run(self, restoreDefinition):
        postUri = "/restore"
        __data__ = None
        __encoded__ = None
        from netbluemind.dataprotect.api.RestoreDefinition import RestoreDefinition
        from netbluemind.dataprotect.api.RestoreDefinition import __RestoreDefinitionSerDer__
        __data__ = __RestoreDefinitionSerDer__().encode(restoreDefinition)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDataProtect_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def saveAll(self):
        postUri = "/_backup"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDataProtect_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def syncWithFilesystem(self):
        postUri = "/_syncfs"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDataProtect_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def updatePolicy(self, rp):
        postUri = "/policy"
        __data__ = None
        __encoded__ = None
        from netbluemind.dataprotect.api.RetentionPolicy import RetentionPolicy
        from netbluemind.dataprotect.api.RetentionPolicy import __RetentionPolicySerDer__
        __data__ = __RetentionPolicySerDer__().encode(rp)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDataProtect_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class SimpleShardStats:
    def __init__(self):
        self.indexName = None
        self.mailboxes = None
        self.aliases = None
        self.docCount = None
        self.deletedCount = None
        self.externalRefreshCount = None
        self.externalRefreshDuration = None
        self.size = None
        pass


class __SimpleShardStatsSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = SimpleShardStats()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        indexNameValue = value['indexName']
        instance.indexName = serder.STRING.parse(indexNameValue)
        mailboxesValue = value['mailboxes']
        instance.mailboxes = serder.SetSerDer(
            serder.STRING).parse(mailboxesValue)
        aliasesValue = value['aliases']
        instance.aliases = serder.SetSerDer(serder.STRING).parse(aliasesValue)
        docCountValue = value['docCount']
        instance.docCount = serder.LONG.parse(docCountValue)
        deletedCountValue = value['deletedCount']
        instance.deletedCount = serder.LONG.parse(deletedCountValue)
        externalRefreshCountValue = value['externalRefreshCount']
        instance.externalRefreshCount = serder.LONG.parse(
            externalRefreshCountValue)
        externalRefreshDurationValue = value['externalRefreshDuration']
        instance.externalRefreshDuration = serder.LONG.parse(
            externalRefreshDurationValue)
        sizeValue = value['size']
        instance.size = serder.LONG.parse(sizeValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        indexNameValue = value.indexName
        instance["indexName"] = serder.STRING.encode(indexNameValue)
        mailboxesValue = value.mailboxes
        instance["mailboxes"] = serder.SetSerDer(
            serder.STRING).encode(mailboxesValue)
        aliasesValue = value.aliases
        instance["aliases"] = serder.SetSerDer(
            serder.STRING).encode(aliasesValue)
        docCountValue = value.docCount
        instance["docCount"] = serder.LONG.encode(docCountValue)
        deletedCountValue = value.deletedCount
        instance["deletedCount"] = serder.LONG.encode(deletedCountValue)
        externalRefreshCountValue = value.externalRefreshCount
        instance["externalRefreshCount"] = serder.LONG.encode(
            externalRefreshCountValue)
        externalRefreshDurationValue = value.externalRefreshDuration
        instance["externalRefreshDuration"] = serder.LONG.encode(
            externalRefreshDurationValue)
        sizeValue = value.size
        instance["size"] = serder.LONG.encode(sizeValue)
        return instance
